package vieon.reactlibrary.ima;


import android.view.View;
import androidx.annotation.StringDef;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.uimanager.events.RCTEventEmitter;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

class ReactEventEmitter {

    private final RCTEventEmitter eventEmitter;

    private int viewId = View.NO_ID;

    ReactEventEmitter(ReactContext reactContext) {
        this.eventEmitter = reactContext.getJSModule(RCTEventEmitter.class);
    }

    private static final String EVENT_ADS_COMPLETED = "onAdsComplete";
    private static final String EVENT_AD_ERROR = "onAdError";
    private static final String EVENT_ADS_LOADED = "onAdsLoaded";
    private static final String EVENT_AD_STARTED = "onAdStarted";

    static final String[] Events = {
            EVENT_ADS_COMPLETED,
            EVENT_AD_ERROR,
            EVENT_ADS_LOADED,
            EVENT_AD_STARTED
    };

    @Retention(RetentionPolicy.SOURCE)
    @StringDef({
            EVENT_ADS_COMPLETED,
            EVENT_AD_ERROR,
            EVENT_ADS_LOADED,
            EVENT_AD_STARTED
    })
    @interface AdsEvents {
    }


    void setViewId(int viewId) {
        this.viewId = viewId;
    }

    void adsCompleted() {
        receiveEvent(EVENT_ADS_COMPLETED, null);
    }
    void adError() {
        receiveEvent(EVENT_AD_ERROR, null);
    }
    void adsLoaded() {
        receiveEvent(EVENT_ADS_LOADED, null);
    }
    void adStarted() { receiveEvent(EVENT_AD_STARTED, null); }

    private void receiveEvent(@AdsEvents String type, WritableMap event) {
        eventEmitter.receiveEvent(viewId, type, event);
    }
}
