package vieon.reactlibrary.ima;

import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.common.MapBuilder;
import com.facebook.react.uimanager.ThemedReactContext;
import com.facebook.react.uimanager.ViewGroupManager;
import java.util.Map;
import javax.annotation.Nullable;

public class ReactIMAWrapperViewManager extends ViewGroupManager<ReactIMAWrapperView> {

  private static final String REACT_CLASS = "RCTImaView";

  private static final int REQUEST_ADS_COMMAND = 0;
  private static final int START_ADS_COMMAND = 1;

  @Override public String getName() {
    return REACT_CLASS;
  }

  @Override protected ReactIMAWrapperView createViewInstance(ThemedReactContext reactContext) {
    return new ReactIMAWrapperView(reactContext);
  }

  @Override public void onDropViewInstance(ReactIMAWrapperView view) {
    super.onDropViewInstance(view);
    view.removeAllListeners();
  }

  @Override public @Nullable Map<String, Object> getExportedCustomDirectEventTypeConstants() {
    MapBuilder.Builder<String, Object> builder = MapBuilder.builder();
    for (String event : ReactEventEmitter.Events) {
      builder.put(event, MapBuilder.of("registrationName", event));
    }
    return builder.build();
  }

  @Override public void receiveCommand(final ReactIMAWrapperView adView, int commandId,
      @Nullable ReadableArray args) {
    switch (commandId) {
      case REQUEST_ADS_COMMAND:
        adView.requestAds(args != null ? args.getString(0) : null,
            args != null ? args.getInt(1) : 0, args != null ? args.getInt(2) : 0);
        break;
      case START_ADS_COMMAND:
        adView.startAds();
        break;
      default:
        break;
    }
  }
}
