import React, { Component } from "react";
import PropTypes from "prop-types";
import {
  StyleSheet,
  requireNativeComponent,
  ViewPropTypes,
  Platform,
  findNodeHandle,
  UIManager
} from "react-native";

const styles = StyleSheet.create({
  base: {
    overflow: "hidden"
  }
});

export default class IMAView extends Component {
  constructor(props) {
    super(props);

    this.state = {};
  }

  componentDidMount() {
    this.videoHandle = findNodeHandle(this._root);
  }

  setNativeProps(nativeProps) {
    this._root.setNativeProps(nativeProps);
  }

  toTypeString(x) {
    switch (typeof x) {
      case "object":
        return x instanceof Date ? x.toISOString() : JSON.stringify(x); // object, null
      case "undefined":
        return "";
      default:
        // boolean, number, string
        return x.toString();
    }
  }

  requestAds = (url, currentTime, duration) => {
    if (Platform.OS === "android") {
      UIManager.dispatchViewManagerCommand(this.videoHandle, 0, [
        url,
        currentTime,
        duration
      ]);
    }
  };

  startAds = () => {
    if (Platform.OS === "android") {
      UIManager.dispatchViewManagerCommand(this.videoHandle, 1, null);
    }
  };

  _assignRoot = component => {
    this._root = component;
  };

  _onAdsComplete = event => {
    if (this.props.onAdsComplete) {
      this.props.onAdsComplete(event.nativeEvent);
    }
  };

  _onAdsError = event => {
    if (this.props.onAdsError) {
      this.props.onAdsError(event.nativeEvent);
    }
  };

  _onAdsLoaded = event => {
    if (this.props.onAdsLoaded) {
      this.props.onAdsLoaded(event.nativeEvent);
    }
  };

  _onAdStarted = event => {
    if (this.props.onAdStarted) {
      this.props.onAdStarted(event.nativeEvent);
    }
  };

  render() {
    const nativeProps = Object.assign({}, this.props);
    Object.assign(nativeProps, {
      style: [styles.base, nativeProps.style]
    });

    return <RCTImaView ref={this._assignRoot} {...nativeProps} />;
  }
}

IMAView.propTypes = {
  onAdError: PropTypes.func,
  onAdsComplete: PropTypes.func,
  onAdsLoaded: PropTypes.func,
  onAdStarted: PropTypes.func,
  ...ViewPropTypes
};

const RCTImaView = requireNativeComponent("RCTImaView", IMAView);
